package name.nathanmcrae.numbersstation;

import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.dataformat.xml.XmlMapper;
import java.io.File;
import java.io.IOException;
import javafx.beans.property.IntegerProperty;
import javafx.beans.property.SimpleIntegerProperty;
import javafx.beans.property.SimpleStringProperty;
import javafx.beans.property.StringProperty;
import javafx.event.Event;
import javafx.fxml.FXML;
import javafx.scene.control.Spinner;
import javafx.scene.control.SpinnerValueFactory;
import javafx.scene.control.TextField;
import javafx.scene.Node;
import javafx.stage.Stage;

public class MainSettingsController {
    private StationSettings settings;
    private StringProperty stationAddress = new SimpleStringProperty();
    private StringProperty stationName = new SimpleStringProperty();
    private IntegerProperty digitsPerGroup = new SimpleIntegerProperty();
    private IntegerProperty messageLength = new SimpleIntegerProperty();

    @FXML
    private TextField stationNameField;

    @FXML
    private TextField stationAddressField;

    @FXML
    private Spinner<Integer> digitsPerGroupSpinner;

    @FXML
    private Spinner<Integer> messageLengthSpinner;

    public MainSettingsController() throws IOException {
        // System.out.println("Created settings controller");
        // File file = new File("setting-test.xml");
        // XmlMapper xmlMapper = new XmlMapper();
        // settings = xmlMapper.readValue(file, NumbersStationSettings.class);
        // settings.setRefreshInterval(settings.getRefreshInterval() + 40);
        // settings.getStations().add(new StationSettings());
    }

    @FXML
    private void initialize() {
        stationNameField.textProperty().bindBidirectional(stationName);
        stationAddressField.textProperty().bindBidirectional(stationAddress);

        digitsPerGroupSpinner.setValueFactory(new SpinnerValueFactory.IntegerSpinnerValueFactory(1, 100, 1));
        messageLengthSpinner.setValueFactory(new SpinnerValueFactory.IntegerSpinnerValueFactory(1, 100, 1));

        digitsPerGroupSpinner.getValueFactory().valueProperty().bindBidirectional(digitsPerGroup.asObject());
        messageLengthSpinner.getValueFactory().valueProperty().bindBidirectional(messageLength.asObject());
    }

    @FXML
    private void handleAddPrefixButtonPress() {
        // TODO
    }

    @FXML
    private void handleCancelButtonPress(Event e) {
        Node node = (Node) e.getSource();
        Stage stage = (Stage) node.getScene().getWindow();
        stage.setUserData(false);
        stage.close();
    }

    @FXML
    private void handleRemovePrefixButtonPress() {
        // TODO
    }

    @FXML
    private void handleSaveButtonPress(Event e) {
        settings.setAddress(stationAddress.get());

        settings.setDigitsPerGroup(digitsPerGroup.get());
        settings.setMessageLength(messageLength.get());

        Node node = (Node) e.getSource();
        Stage stage = (Stage) node.getScene().getWindow();
        stage.setUserData(true);
        stage.close();
    }

    public StringProperty stationAddressProperty() {
        return stationAddress;
    }

    public void setStationSettings(StationSettings newSettings) {
        settings = newSettings;
        stationName.set(settings.getName());
        digitsPerGroup.set(settings.getDigitsPerGroup());
        messageLength.set(settings.getMessageLength());
    }
}
